/* Program name: clnttst                                            */
/* Author: Didi Dotan */
/* Function:                                                        */
/*   clnttst is a C sample program which demonstrates how to use    */
/*   the following :                                                */
/*     1) MQCONNX -  the connect call                               */
/*     2) MQCNO   -  The V2 structure that allows the client to     */
/*                   choose the qmgr without using MQSERVER or      */
/*                   the client connection channel table.           */
/*     3) MQCD    -  The Channel Defenition Structure, this         */
/*                   combined with the MQCD_CLIENT_CONN_DEFAULT     */
/*                   will be used to point to correct channel.      */
/*   Notes :                                                        */
/*   This program was linked with mqic32.lib.                       */
/*   I used the default protocol which is TCP/IP                    */
/*   clnttst has no input parms.                                    */
/********************************************************************/
#include <cmqc.h>      /* MQ Header Files basic and                 */
#include <cmqxc.h>     /* Channel defs                              */
#include <stdio.h>     /* IO header                                 */
#include <string.h>    /* String functions                          */
int main()
{
    MQHCONN    hConn;        /* Connection handle                   */
    MQHOBJ     hObject;      /* Object handle                       */
    MQCHAR48   qmgrName;     /* Name of queue manager               */
    MQLONG     iCompCode;    /* Completion code                     */
    MQLONG     iReason;      /* Reason code                         */
    MQLONG     iMessageLen;  /* Messsage Length                     */
    MQBYTE     buffer[1000];          /* Message data buffer        */
    MQLONG      iOpenOptions  ;
    /* These are the MQ Structs to be used in this program          */
    MQOD    mqod = {MQOD_DEFAULT};    /* Object description         */
    MQMD    mqmd = {MQMD_DEFAULT};    /* Message Descriptor         */
    MQPMO   mqpmo = {MQPMO_DEFAULT};  /* Put message options        */
    /* These are the special structures used          */
    MQCNO   mqcno = {MQCNO_DEFAULT} ; /* Connection options         */
    MQCD    mqcd  = {MQCD_CLIENT_CONN_DEFAULT};  /* Channel Defs    */
    /* Defined in cmqxc.h             */
/* This part emulates data retrived from a database or LDAP Server. */
    /* I use the following:           */
    /*  1) qmgrName = ""              */
    /*  2) mqcd.ConnectionName = 192.168.1.34 = my dev server       */
    /*  3) mqcd.ChannelName = SYSTEM.DEF.SVRCONN = def server


    /*  can also retrive data such as queue name and such           */
    memset( qmgrName , 0 , MQ_Q_MGR_NAME_LENGTH) ;
    strncpy(mqcd.ConnectionName,
            "192.168.1.34",
            MQ_CONN_NAME_LENGTH);
    strncpy(mqcd.ChannelName,
            "SYSTEM.DEF.SVRCONN",
            MQ_CHANNEL_NAME_LENGTH);
/* Point the MQCNO to the client connection definition and set its


/* or the ClientConnPtr will be ignored... */
   mqcno.ClientConnPtr = &mqcd;
   mqcno.Version = MQCNO_VERSION_2;
/* MQCONNX - (Queue Manager Name, MQCNO, Connection handle, Completion


   Reason code ) */
    MQCONNX(qmgrName,
         &mqcno,
         &hConn,
         &iCompCode,
         &iReason);
/* From here on it is a normal MQSeries program, but bear in mind, when


    if (iCompCode == MQCC_FAILED)
    {
         printf("MQCONN failed with reason code %ld\n", iReason);
         return(iReason);
    }
    iOpenOptions   = MQOO_OUTPUT + MQOO_FAIL_IF_QUIESCING;
    strncpy(mqod.ObjectName, "SYSTEM.DEFAULT.LOCAL.QUEUE", MQ_Q_NAME_LENGTH);
    /*  MQOPEN   */
    MQOPEN(hConn,
         &mqod,
         iOpenOptions,
         &hObject,
         &iCompCode,
         &iReason);
    if (iCompCode == MQCC_FAILED)
    {
         printf("MQOPEN failed with reason code %ld\n", iReason);
         return(iReason);
    }
    strcpy (buffer , "Hello from Client") ;
    memcpy (mqmd.Format , "MQSTR   " , 8 );
    iMessageLen = strlen(buffer)          ;
    MQPUT(hConn,
         hObject,
         &mqmd,
         &mqpmo,
         iMessageLen,
         buffer,
         &iCompCode,
         &iReason);
    if (iCompCode == MQCC_FAILED)
    {
         printf("MQPUT failed with reason code %ld\n", iReason);
         return(iReason);
    }
    /* MQCLOSE   */
    MQCLOSE(hConn, &hObject, MQCO_NONE, &iCompCode, &iReason);
    /* MQDISC - Do not forget to use DISC !!! This is Client Code   */
    MQDISC(&hConn, &iCompCode, &iReason);
    return(0);
}
